.. _api:

API Reference
=============

.. currentmodule:: gordon_janitor

main
----

.. automodule:: gordon_janitor.main

.. autofunction:: gordon_janitor.main.setup


plugins_loader
--------------

.. automodule:: gordon.plugins_loader

.. autofunction:: gordon.plugins_loader.load_plugins
